#version 330 core

#define SPRITE_OUT_COLOR
#define SPRITE_OUT_TEXCOORD
#define SPRITE_OUT_TEXCOORD_RAW
#define SPRITE_OUT_CUSTOM
#define SPRITE_OUT_TEXREGION

#include "lib/sprite_default.vert.glslh"
