#version 330 core

// Generated by gen-blur-shader.py. kernel size = 5; sigma = 1.25

#include "interface/standard.glslh"
#include "lib/blur/blur5.glslh"

UNIFORM(1) vec2 blur_resolution;
UNIFORM(2) vec2 blur_direction;

void main(void) {
    fragColor = sample_blur5(tex, texCoord, blur_direction / blur_resolution);
}
